/*
 * @Author: dminyi 1301963064@qq.com
 * @Date: 2024-08-09 09:59:43
 * @LastEditors: dminyi 1301963064@qq.com
 * @LastEditTime: 2024-08-13 16:05:42
 * @FilePath: \gzDyh\gz-customerSystem\src\views\basicInformation\organization\index.jsx
 * @Description: 来访登记
 */

import React, { useState, useEffect, useRef } from "react";
import NewPage from '../../../components/NewPage';
import RegisterTab from '../../../components/registerTab';
import PersonCard from '../../../components/personCard';
import * as $$ from '../../../utils/utility';
import { add, question1 } from '../../../assets/images';
import { Row, Col, Space, Tooltip } from 'antd';
import { Form, Input, Button, Radio, Select, DatePicker, Cascader } from '@arco-design/web-react';
import "@arco-design/web-react/dist/css/arco.css";
import TableView from '../../../components/TableView';

const RadioGroup = Radio.Group;// 根据调解案号获取纠纷登记信息
const FormItem = Form.Item;
const Option = Select.Option;
const InputSearch = Input.Search;



function getCaseDataApi(submitData) {
	return $$.ax.request({ url: `caseInfo/getCaseInfo?id=${submitData}`, type: 'get', service: 'mediate' });
}



const Organization = () => {
	const formRef = useRef();

	// tabs当前选择的标签信息
	const [tabsActive, setTabsActive] = useState('1');
	const [visible, setVisible] = useState(false);
	const [selectedCity, setSelectedCity] = useState('Beijing');

	const tabs = [
		{ label: '事件登记', key: '1' },
		{ label: '事件流转', key: '2' },
		{ label: '办理反馈', key: '3' },
		{ label: '申请结案', key: '4' },
		{ label: '当事人评价', key: '5' },
		{ label: '结案归档', key: '6', img1: true },

	];


	const fakeData = [
		{
			id: 3,
			perClassName: '申请方当事人',
			trueName: '蓝海科技有限公司',
			mobile: '9144010188453Z',
			company: true,
			companyName: '张晓梅',//公司法人
			partyType: 'applicant',//申请人
		},
		{
			id: 1,
			perClassName: '申请方代理人',
			trueName: '王小明',
			mobile: '410106198802121125',
			person: true,
			personNumber: '13388888888',//联系方式
			partyType: 'applicant',
		},
		{
			id: 2,
			perClassName: '被申请方当事人',
			trueName: '大海科技有限公司',
			mobile: '13800000002',
			company: true,
			companyName: '郭小聪',//公司法人
			partyType: 'respondent',//被申请方
			remark: [{ label: '精神障碍', color: '#C64FBE' }, { label: '吸毒', color: '#D8A247' }, { label: '社区矫正', color: '#B82F6E' }, { label: '刑满释放', color: '#199C8F' }, { label: '流浪', color: '#3ECB7A' }, { label: '重点青少年', color: '#117AC1' }, { label: '涉稳涉访', color: '#6865D7' }, { label: '潜在风险', color: '#2661CE' }]
		},
		{
			id: 2,
			perClassName: '被申请方代理人',
			trueName: '张三',
			mobile: '13800000002',
			person: true,
			personNumber: '13399999999',//联系方式
			partyType: 'respondent',
			remark: [{ label: '精神障碍', color: '#C64FBE' }]
		},
		{
			id: 2,
			perClassName: '被申请方代理人',
			trueName: '张三',
			mobile: '13800000002',
			person: true,
			personNumber: '13399999999',//联系方式
			partyType: 'respondent',
			remark: [{ label: '精神障碍', color: '#C64FBE' }]
		},
		{
			id: 2,
			perClassName: '被申请方代理人',
			trueName: '张三',
			mobile: '13800000002',
			person: true,
			personNumber: '13399999999',//联系方式
			partyType: 'respondent',
			remark: [{ label: '精神障碍', color: '#C64FBE' }]
		},
	];

	const fakeData1 = [
		{
			id: 1,
			caseNo: 'A20230101',
			judicNo: 'J20230101',
			perClassName: '自然人',
			inputUserName: '张三',
			mediateUserName: '李四',
			judgeName: '王五',
			mediator: '赵六',
			handlerUserName: '钱七',
			returnUserName: '孙八',
			expireTime: '2023-08-10T08:00:00.000Z',
			processName: '进行中',
			otherMediator: '周九',
			canalName: '网络',
			judicResult: '通过',
			assistName: '吴十',
			mediTypeName: '民事调解',
			serieStatus: '1', // 1 表示非系列案，2 表示系列案
			// 更多字段...
		},
		// 更多数据...
	];

	// 列配置
	const fakeColumns = [
		{
			title: '序号',
			dataIndex: 'caseNo',
			key: 'caseNo',
		},
		{
			title: '材料类型',
			dataIndex: 'judicNo',
			key: 'judicNo',
		},
		{
			title: '材料数量',
			dataIndex: 'perClassName',
			key: 'perClassName',
		},
		{
			title: '材料名称',
			dataIndex: 'perClassName',
			key: 'perClassName',
		},
		{
			title: '上传时间',
			dataIndex: 'perClassName',
			key: 'perClassName',
		},
		{
			title: '操作',
			dataIndex: 'perClassName',
			key: 'perClassName',
			render: (text) => (
				<div style={{ display: 'flex', color: '#1A6FB8', gap: '16px' }}>
					<div>查看</div>
					<div>删除</div>
					<div>下载</div>
					<div>上传</div>
				</div>
			)
		},
		// 更多列配置...
	];

	const options = [
		{
			value: 'beijing',
			label: 'Beijing',
			children: [
				{
					value: 'Beijing',
					label: 'Beijing',
					children: [
						{
							value: 'chaoyang',
							label: 'Chaoyang',
						},
					],
				},
			],
		},
		{
			value: 'shanghai',
			label: 'Shanghai',
			children: [
				{
					value: 'shanghaishi',
					label: 'Shanghai',
					children: [
						{
							value: 'huangpu',
							label: 'Huangpu',
						},
					],
				},
			],
		},
	];

	function onSelect(dateString, date) {
		console.log('onSelect', dateString, date);
	}

	function onChange(dateString, date) {
		console.log('onChange: ', dateString, date);
	}

	function onOk(dateString, date) {
		console.log('onOk: ', dateString, date);
	}


	function handleCheckParty() {
		console.log('check party');
	}


	const onReload = () => {
		console.log('表格数据刷新');
	};

	//获取当前时间
	function getFormattedDateTime() {
		let now = new Date();
		let year = now.getFullYear();
		let month = (now.getMonth() + 1).toString().padStart(2, '0'); // 月份是从0开始的，所以要+1  
		let day = now.getDate().toString().padStart(2, '0');
		let hours = now.getHours().toString().padStart(2, '0');
		let minutes = now.getMinutes().toString().padStart(2, '0');

		return `${year}-${month}-${day} ${hours}:${minutes}`;
	}

	//保存信息
	const handleSave = async () => {
		if (formRef.current) {
			try {
				await formRef.current.validate((errors, values) => {
					console.log(errors, values);
				});
				// Message.info('校验通过，提交成功！');
			} catch (_) {
				console.log(formRef.current.getFieldsError());
				// Message.error('校验失败，请检查字段！');
			}
		}
	}


	return (
		<div style={{ position: 'relative' }}>
			<NewPage
				pageHead={
					{ breadcrumbData: [{ title: '工作台' }, { title: '来访登记' }], title: '来访登记' }
				}
			>
				<RegisterTab tabs={tabs} activeKey={tabsActive} onChange={(activeKey) => setTabsActive(activeKey)} style={{ background: '#fff' }} />
				{tabsActive === '1' &&
					<div className='dataSync-page'>
						<Col span={24} style={{ display: 'flex', alignItems: 'center' }}>
							<Space size='small'>
								<div className='MediationInfo-subTitle' style={{ marginTop: '-6px' }}></div><h5>当事人信息</h5>
							</Space>
						</Col>
						<div>
							<PersonCard
								isCheck={true}
								partyType={'applicant'} // 这里设定为申请人
								data={fakeData}
								handleCheckParty={handleCheckParty}
							/>
						</div>
						<Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '8px' }}>
							<Space size='small'>
								<div className='MediationInfo-subTitle' style={{ marginTop: '-6px' }}></div><h5>纠纷基本情况</h5>
							</Space>
						</Col>
						<Form
							ref={formRef}
							layout='vertical'
							requiredSymbol={false}
							initialValues={{
								level: '三级',
								visitingTime: getFormattedDateTime(),
							}}
						>
							<Row gutter={[32, 0]}>
								<Col span={8}>
									<FormItem label='事项等级' field='level' tooltip={<div className='question'>Username is required </div>} >
										<Select placeholder='Select city' allowClear>
											{['一级', '二级', '三级', '四级'].map((option, index) => (
												<Option key={option} value={option}>
													{option}
												</Option>
											))}
										</Select>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem label='来访时间' field='visitingTime'>
										<DatePicker
											style={{ width: '100%' }}
											format='YYYY-MM-DD HH:mm'
											showTime={true}
										/>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem label='来访人数（人）' field='visitingNumber'>
										<Input placeholder='请填写' />
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem
										label={(<div style={{ display: 'flex' }}>纠纷类型<div className="must">必填</div></div>)}
										rules={[{ required: true }]}
										field='disputeType'
									>
										<Select initialValue='Beijing' placeholder='请选择' allowClear>
											{['邻里纠纷', '劳动争议纠纷', '劳动纠纷', '经济纠纷'].map((option, index) => (
												<Option key={option} value={option}>
													{option}
												</Option>
											))}
										</Select>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem
										label={(<div style={{ display: 'flex' }}>纠纷发生时间<div className="must">必填</div></div>)}
										rules={[{ required: true }]}
										field='disputeTime'
									>
										<DatePicker
											style={{ width: '100%' }}
											placeholder='请选择'
											format='YYYY-MM-DD HH:mm'
											showTime={true}
										/>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem
										label={(<div style={{ display: 'flex' }}>纠纷发生地点<div className="must">必填</div></div>)}
										rules={[{ required: true }]}
										field='disputeAddress'
									>
										<InputSearch
											searchButton='选择'
											placeholder='选择纠纷发生地的详细地址'
										/>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem label='问题属地'>
										<Cascader
											placeholder='Please select ...'
											options={options}
											onChange={(value, option) => {
												console.log(value, option);
											}}
											defaultValue={['shanghai', 'shanghaishi', 'huangpu']}
											allowClear
										/>
									</FormItem>
								</Col>
								<Col span={8}>
									<FormItem label='涉及人数（人）'>
										<Input placeholder='请填写' />
									</FormItem>
								</Col>

								<Col span={8}>
									<FormItem label='涉及金额（元）'>
										<Input placeholder='请填写' />
									</FormItem>
								</Col>
								<Col span={24}>
									<FormItem
										label={<div style={{ display: 'flex' }}>
											事项概况
											<Tooltip title='1111'>
												<img src={question1} alt="" style={{ width: '13px', height: '13px', marginTop: '4px', marginLeft: '4px' }} />
											</Tooltip>
											<div className="must">必填</div>
											<div style={{ marginLeft: '8px', color: '#1A6FB8', fontSize: '14px', cursor: 'pointer' }}>识别上传材料</div>
										</div>
										}
									>
										<Input.TextArea
											maxLength={2000}
											showWordLimit
											rows={5}
											placeholder='请填写问题发生的起因、过程和结果'
											wrapperStyle={{ width: '100%' }}
										/>
									</FormItem>
								</Col>
								<Col span={24}>
									<FormItem
										label={<div style={{ display: 'flex' }}>
											申请请求
											<Tooltip title='1111'>
												<img src={question1} alt="" style={{ width: '13px', height: '13px', marginTop: '4px', marginLeft: '4px' }} />
											</Tooltip>
											<div className="must">必填</div>
											<div style={{ marginLeft: '8px', color: '#1A6FB8', fontSize: '14px', cursor: 'pointer' }}>识别上传材料</div>
										</div>
										}
									>
										<Input.TextArea
											maxLength={2000}
											showWordLimit
											rows={5}
											placeholder='希望相关部门如何处理，建议分条描述，如请求1，请求2...'
											wrapperStyle={{ width: '100%' }}
										/>
									</FormItem>
								</Col>
								<div style={{ marginLeft: '16px', padding: '12px 16px', backgroundColor: '#EFF8FF', borderRadius: '2px' }}>
									<FormItem label='是否重大矛盾纠纷' style={{ marginBottom: '-20px' }}>
										<RadioGroup options={['否', '是']} style={{ marginBottom: 20 }} />
									</FormItem>
								</div>
							</Row>

						</Form>
						<Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '8px', marginTop: '20px' }}>
							<Space size='small'>
								<div className='MediationInfo-subTitle' style={{ marginTop: '-6px' }}></div><h5>事件材料</h5>
							</Space>
						</Col>
						<TableView
							columns={fakeColumns}
							dataSource={fakeData1}
							size="small"
							rowKey="id"
							bordered={true}
							style={{ marginBottom: '60px' }}
						/>
						<div className="dataSync-excel">
							<Space size="large" style={{ margin: '4px 14px' }}>
								<Button type="primary" style={{ backgroundColor: '#1A6FB8' }} onClick={handleSave}>保存信息</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }}>预览信息</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }}>提交信息</Button>
								<Button type='outline' style={{ color: '#1A6FB8', border: '1px solid #1A6FB8' }}>自行受理</Button>
								<Button type='secondary'>返回上级页面</Button>
							</Space>
						</div>
					</div>

				}
			</NewPage>

		</div>
	)
}

export default Organization;